@@ -17,8 +17,7 @@ from . import pprint
 def parser(subparsers, _):
   """Adds the init parser to the given subparsers object."""
   desc = (
-      'create an empty Gitless\'s repository or create one from an existing '
-      'remote repository')
+      'create an empty git repository or clone remote')
   init_parser = subparsers.add_parser(
       'init', help=desc, description=desc.capitalize())
   init_parser.add_argument(
