@@ -58,6 +58,13 @@ GL_STATUS_TRACKED = 2
 GL_STATUS_IGNORED = 3
 
 
+def error_on_none(path):
+  """Raise a KeyError if the ```path``` argument is None."""
+  if path is None:
+    raise KeyError('path')
+  return path
+
+
 def init_repository(url=None):
   """Creates a new Gitless's repository in the cwd.
 
@@ -67,7 +74,7 @@ def init_repository(url=None):
   """
   cwd = os.getcwd()
   try:
-    pygit2.discover_repository(cwd)
+    error_on_none(pygit2.discover_repository(cwd))
     raise GlError('You are already in a Gitless repository')
   except KeyError:  # Expected
     if not url:
@@ -108,7 +115,7 @@ class Repository(object):
   def __init__(self):
     """Create a Repository out of the current working repository."""
     try:
-      path = pygit2.discover_repository(os.getcwd())
+      path = error_on_none(pygit2.discover_repository(os.getcwd()))
     except KeyError:
       raise NotInRepoError('You are not in a Gitless\'s repository')
 
@@ -1020,7 +1027,7 @@ class Branch(object):
     """Fuse the given commits onto this branch.
 
     Args:
-      src: the branch (Brach obj) to fuse commits from.
+      src: the branch (Branch obj) to fuse commits from.
       ip: id of the commit to act as the insertion point. The commits to fuse
         are inserted after this commit. ip has to correspond to one of the
         divergent commits from self or the divergent point.
@@ -1333,10 +1340,18 @@ OpCb = collections.namedtuple(
     'OpCb', ['apply_ok', 'apply_err', 'save', 'restore_ok'])
 
 def stdout(p):
-  return p.stdout.decode(ENCODING)
+  try:
+      pstdout = p.stdout.decode(ENCODING)
+  except AttributeError:
+      pstdout = p.stdout
+  return pstdout
 
 def stderr(p):
-  return p.stderr.decode(ENCODING)
+  try:
+      pstderr = p.stderr.decode(ENCODING)
+  except AttributeError:
+      pstderr = p.stderr
+  return pstderr
 
 def walker(git_repo, target, reverse):
   flags = pygit2.GIT_SORT_TOPOLOGICAL | pygit2.GIT_SORT_TIME
